package com.someco.scripts;

import java.util.HashMap;
import java.util.Map;

import org.alfresco.model.ContentModel;
import org.alfresco.service.cmr.repository.NodeRef;
import org.alfresco.service.cmr.repository.NodeService;
import org.alfresco.service.namespace.NamespaceService;
import org.alfresco.service.namespace.QName;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.extensions.webscripts.DeclarativeWebScript;
import org.springframework.extensions.webscripts.Status;
import org.springframework.extensions.webscripts.WebScriptRequest;

/**
 * This is the controller for the Move Category web script.
 * 
 * @author jpotts 
 */
public class MoveCategory extends DeclarativeWebScript {

	Log logger = LogFactory.getLog(MoveCategory.class);
			
	// Dependencies
	private NodeService nodeService;
	
	@Override
	protected Map<String, Object> executeImpl(WebScriptRequest req, Status status) {
		
		final String sourceNodeRefString = req.getParameter("sourceNodeRef");
		final String targetNodeRefString = req.getParameter("targetNodeRef");
		
		// check required args
		if (sourceNodeRefString == null || targetNodeRefString == null) {
			logger.error("Source or target node ref not set");
			status.setCode(400);			
			status.setMessage("Required data has not been provided");
			status.setRedirect(true);
		}

		// check to see if the source node ref exists
		NodeRef sourceNodeRef = new NodeRef(sourceNodeRefString);
		if (!nodeService.exists(sourceNodeRef)) {
			String message = "Source node ref does not exist: " + sourceNodeRefString;
			logger.error(message);
			status.setCode(500);			
			status.setMessage(message);
			status.setRedirect(true);			
		}
		String sourceName = (String) nodeService.getProperty(sourceNodeRef, ContentModel.PROP_NAME);

		// check to see if the target node ref exists
		NodeRef targetNodeRef = new NodeRef(targetNodeRefString);
		if (!nodeService.exists(targetNodeRef)) {
			String message = "Source node ref does not exist: " + targetNodeRefString;
			logger.error(message);
			status.setCode(500);			
			status.setMessage(message);
			status.setRedirect(true);			
		}
		String targetName = (String) nodeService.getProperty(targetNodeRef, ContentModel.PROP_NAME);
		
		// move the node
		nodeService.moveNode(sourceNodeRef, targetNodeRef, ContentModel.ASSOC_SUBCATEGORIES, QName.createQName(NamespaceService.CONTENT_MODEL_1_0_URI, sourceName));
		
		// set up the model
		Map<String, Object> model = new HashMap<String, Object>();
		model.put("sourceNodeRef", sourceNodeRefString);
		model.put("sourceName", sourceName);
		model.put("targetNodeRef", targetNodeRefString);
		model.put("targetName", targetName);
		
		return model;
	}

	public void setNodeService(NodeService nodeService) {
		this.nodeService = nodeService;
	}

}
